@@ -102,6 +102,8 @@ test_color_parse_css(void)
         assert_color_parse_value("hsl (0, 100%, 50%)", rgba(1.0, 0.0, 0.0, 1.0), color_format::CSSLIKE);
         assert_color_parse_value("hsla (120, 255, 50%, 0.1)", rgba(0.0, 1.0, 0.0, 0.1), color_format::CSSLIKE);
         assert_color_parse_value("hsl(180, 100%, 25%)", rgba(0.0, 0.5, 0.5, 1.0), color_format::CSSLIKE);
+
+        assert_color_parse_value("hsl(360, 100, 25)", rgba(0.5, 0.0, 0.0, 1.0), color_format::CSSLIKE);
 }
 
 static void
@@ -165,7 +167,7 @@ static void
 test_color_to_string (void)
 {
         auto test = [](std::string str,
-                       bool alpha = false) constexpr noexcept -> void
+                       bool alpha = false) noexcept -> void
         {
                 auto const value = parse<rgba>(str);
                 assert(value);
